package services

import (
	"encoding/json"
	"eta/eta_mini_api/utils"
	"io"
	"net/http"
	"strconv"
	"time"
)

type ChartPermission struct {
	ChartPermissionId     int       `orm:"column(chart_permission_id);pk" description:"问题ID" json:"chart_permission_id"`
	ChartPermissionName   string    `description:"名称" json:"chart_permission_name"`
	PermissionName        string    `description:"权限名" json:"permission_name"`
	Sort                  int       `description:"排序" json:"sort"`
	Enabled               int       `description:"是否可用" json:"enabled"`
	CreatedTime           time.Time `description:"创建时间" json:"created_time"`
	LastUpdatedTime       time.Time `description:"更新时间" json:"last_updated_time"`
	TeleconferenceSort    int       `description:"电话会类型排序" json:"teleconference_sort"`
	Remark                string    `description:"备注" json:"remark"`
	ClassifyName          string    `description:"分类名称" json:"classify_name"`
	ProductName           string    `description:"产品名称" json:"product_name"`
	ProductId             int       `description:"产品ID" json:"product_id"`
	ImageURL              string    `orm:"column(image_url);" description:"图片地址" json:"image_url"`
	ShowType              int       `description:"1:查研观向小程序展示" json:"show_type"`
	IsOther               int       `description:"是否是其他，用于查研观向小程序后台展示" json:"is_other"`
	IsReport              int       `description:"是否是报告，用于查研观向小程序前台报告展示" json:"is_report"`
	CygxAuth              int       `description:"是否是权限，用于查研观向小程序前台权限校验" json:"cygx_auth"`
	PermissionType        int       `description:"1主观，2客观" json:"permission_type"`
	YbImgUrl              string    `description:"研报小程序报告列表icon" json:"yb_img_url"`
	ProductPermissionName string    `description:"种类权限名称" json:"product_permission_name"`
	PriceDrivenState      int       `description:"品种价格驱动开启状态 0-关闭 1-开启" json:"price_driven_state"`
	ImageUrlM             string    `description:"图片地址(查研观向移动端)" json:"image_url_m"`
	ParentId              int       `description:"父级权限id" json:"parent_id"`
	IsPublic              int       `description:"是否是公有权限1:公有权限，0私有权限" json:"is_public"`
}

type ChartPermissionResp struct {
	Ret    int
	Data   []*ChartPermission
	Msg    string
	ErrMsg string
}

func GetChartPermissionSecondList(chartPermissionId int) (resp *ChartPermissionResp, err error) {
	url := utils.ETA_MINI_BRIDGE_URL + "/chart_permission/second/list"
	client := &http.Client{}
	if url != "" {
		url += "?chartPermissonId=" + strconv.Itoa(chartPermissionId)
	}
	// 提交请求
	req, err := http.NewRequest("GET", url, nil)
	if err != nil {
		return
	}
	nonce := utils.GetRandStringNoSpecialChar(16)
	timestamp := time.Now().Format(utils.FormatDateTimeUnSpace)
	signature := utils.GetSign(nonce, timestamp, utils.ETA_MINI_APPID, utils.ETA_MINI_APP_SECRET)
	//增加header选项
	req.Header.Add("Nonce", nonce)
	req.Header.Add("Timestamp", timestamp)
	req.Header.Add("Appid", utils.ETA_MINI_APPID)
	req.Header.Add("Signature", signature)
	req.Header.Set("Content-Type", "application/json")

	response, err := client.Do(req)
	if err != nil {
		return
	}
	defer response.Body.Close()

	body, err := io.ReadAll(response.Body)

	if err != nil {
		return
	}
	utils.FileLog.Info("result:" + string(body))
	err = json.Unmarshal(body, &resp)
	if err != nil {
		return
	}
	return

}

func GetChartPermissionList() (resp *ChartPermissionResp, err error) {
	url := utils.ETA_MINI_BRIDGE_URL + "/chart_permission/list"
	client := &http.Client{}
	// 提交请求
	req, err := http.NewRequest("GET", url, nil)
	if err != nil {
		return
	}
	nonce := utils.GetRandStringNoSpecialChar(16)
	timestamp := time.Now().Format(utils.FormatDateTimeUnSpace)
	signature := utils.GetSign(nonce, timestamp, utils.ETA_MINI_APPID, utils.ETA_MINI_APP_SECRET)
	//增加header选项
	req.Header.Add("Nonce", nonce)
	req.Header.Add("Timestamp", timestamp)
	req.Header.Add("Appid", utils.ETA_MINI_APPID)
	req.Header.Add("Signature", signature)
	req.Header.Set("Content-Type", "application/json")

	response, err := client.Do(req)
	if err != nil {
		return
	}
	defer response.Body.Close()

	body, err := io.ReadAll(response.Body)

	if err != nil {
		return
	}
	utils.FileLog.Info("result:" + string(body))
	err = json.Unmarshal(body, &resp)
	if err != nil {
		return
	}
	return

}

func GetChartPermissionAllList() (resp *ChartPermissionResp, err error) {
	url := utils.ETA_MINI_BRIDGE_URL + "/chart_permission/allList"
	client := &http.Client{}
	// 提交请求
	req, err := http.NewRequest("GET", url, nil)
	if err != nil {
		return
	}
	nonce := utils.GetRandStringNoSpecialChar(16)
	timestamp := time.Now().Format(utils.FormatDateTimeUnSpace)
	signature := utils.GetSign(nonce, timestamp, utils.ETA_MINI_APPID, utils.ETA_MINI_APP_SECRET)
	//增加header选项
	req.Header.Add("Nonce", nonce)
	req.Header.Add("Timestamp", timestamp)
	req.Header.Add("Appid", utils.ETA_MINI_APPID)
	req.Header.Add("Signature", signature)
	req.Header.Set("Content-Type", "application/json")

	response, err := client.Do(req)
	if err != nil {
		return
	}
	defer response.Body.Close()

	body, err := io.ReadAll(response.Body)

	if err != nil {
		return
	}
	utils.FileLog.Info("result:" + string(body))
	err = json.Unmarshal(body, &resp)
	if err != nil {
		return
	}
	return

}
